aboutsummaryrefslogtreecommitdiffstats
path: root/src/gaudio/driver_play.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gaudio/driver_play.h')
-rw-r--r--src/gaudio/driver_play.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gaudio/driver_play.h b/src/gaudio/driver_play.h
index 72ad4747..d140c2c9 100644
--- a/src/gaudio/driver_play.h
+++ b/src/gaudio/driver_play.h
@@ -42,19 +42,19 @@ extern "C" {
* @iclass
* @notapi
*/
-GAudioData *gaudioPlayGetDataBlockI(void);
+GDataBuffer *gaudioPlayGetDataBlockI(void);
/**
* @brief Release a block of audio data to the free list
*
* @param[in] paud The GAudioData block to be released.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO play drivers.
*
* @iclass
* @notapi
*/
-void gaudioPlayReleaseDataBlockI(GAudioData *paud);
+void gaudioPlayReleaseDataBlockI(GDataBuffer *paud);
/**
* @brief Signal that all playing has now stopped
@@ -42,19 +42,19 @@ extern "C" {
* @brief Release a block of audio data to the free list
*
- * @param[in] paud The GAudioData block to be released.
+ * @param[in] paud The GDataBuffer block to be released.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO play drivers.